# Yet Another ECS CTL tool

```
pip install ya-ecs-ctl

```

Adds binary:


```
ecs

```

```

Usage: ecs [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  ci       Interact with Container Instances
  cluster  Interact with Cluster
  ec2      Interact with EC2 Instances
  service  Interact with Service
  task     Interact with Task


```

## Alternatives..

https://github.com/diegoacuna/ecs-ctl
> Manage Amazon ECS like with kubectl.

https://github.com/labd/ecs-deplojo/
> Deployment tool for Amazon ECS.

https://github.com/fabfuel/ecs-deploy
> ecs-deploy simplifies deployments on Amazon ECS by providing a convinience CLI tool for complex actions, which are executed pretty often.

https://github.com/cuttlesoft/ecs-deploy.py
> Python script to instigate an automatic blue/green deployment using the Task Definition and Service entities in Amazon's ECS.

https://github.com/boroivanov/ecs-tools
> 
ECS Tools cli aims to make deploying to ECS Fargate easier. It also provides an easy way to scale and update environment variables.




